@@ -2,55 +2,71 @@
 
 export PREFIX="$(pwd)/libsodium-apple"
 export MACOS_ARM64_PREFIX="${PREFIX}/tmp/macos-arm64"
+export MACOS_ARM64E_PREFIX="${PREFIX}/tmp/macos-arm64e"
 export MACOS_X86_64_PREFIX="${PREFIX}/tmp/macos-x86_64"
 export IOS32_PREFIX="${PREFIX}/tmp/ios32"
 export IOS32s_PREFIX="${PREFIX}/tmp/ios32s"
 export IOS64_PREFIX="${PREFIX}/tmp/ios64"
+export IOS64E_PREFIX="${PREFIX}/tmp/ios64e"
 export IOS_SIMULATOR_ARM64_PREFIX="${PREFIX}/tmp/ios-simulator-arm64"
+export IOS_SIMULATOR_ARM64E_PREFIX="${PREFIX}/tmp/ios-simulator-arm64e"
 export IOS_SIMULATOR_I386_PREFIX="${PREFIX}/tmp/ios-simulator-i386"
 export IOS_SIMULATOR_X86_64_PREFIX="${PREFIX}/tmp/ios-simulator-x86_64"
 export WATCHOS32_PREFIX="${PREFIX}/tmp/watchos32"
 export WATCHOS64_32_PREFIX="${PREFIX}/tmp/watchos64_32"
 export WATCHOS64_PREFIX="${PREFIX}/tmp/watchos64"
+export WATCHOS64E_PREFIX="${PREFIX}/tmp/watchos64e"
 export WATCHOS_SIMULATOR_ARM64_PREFIX="${PREFIX}/tmp/watchos-simulator-arm64"
+export WATCHOS_SIMULATOR_ARM64E_PREFIX="${PREFIX}/tmp/watchos-simulator-arm64e"
 export WATCHOS_SIMULATOR_I386_PREFIX="${PREFIX}/tmp/watchos-simulator-i386"
 export WATCHOS_SIMULATOR_X86_64_PREFIX="${PREFIX}/tmp/watchos-simulator-x86_64"
 export TVOS_PREFIX="${PREFIX}/tmp/tvos"
+export TVOSE_PREFIX="${PREFIX}/tmp/tvose"
 export TVOS_SIMULATOR_ARM64_PREFIX="${PREFIX}/tmp/tvos-simulator-arm64"
+export TVOS_SIMULATOR_ARM64E_PREFIX="${PREFIX}/tmp/tvos-simulator-arm644"
 export TVOS_SIMULATOR_X86_64_PREFIX="${PREFIX}/tmp/tvos-simulator-x86_64"
 export VISIONOS_PREFIX="${PREFIX}/tmp/visionos"
+export VISIONOSE_PREFIX="${PREFIX}/tmp/visionose"
 export VISIONOS_SIMULATOR_PREFIX="${PREFIX}/tmp/visionos-simulator"
+export VISIONOSE_SIMULATOR_PREFIX="${PREFIX}/tmp/visionose-simulator"
 export CATALYST_ARM64_PREFIX="${PREFIX}/tmp/catalyst-arm64"
+export CATALYST_ARM64E_PREFIX="${PREFIX}/tmp/catalyst-arm64e"
 export CATALYST_X86_64_PREFIX="${PREFIX}/tmp/catalyst-x86_64"
 export LOG_FILE="${PREFIX}/tmp/build_log"
 export XCODEDIR="$(xcode-select -p)"
 
 export MACOS_VERSION_MIN=${MACOS_VERSION_MIN-"10.10"}
-export IOS_SIMULATOR_VERSION_MIN=${IOS_SIMULATOR_VERSION_MIN-"9.0.0"}
 export IOS_VERSION_MIN=${IOS_VERSION_MIN-"9.0.0"}
-export WATCHOS_SIMULATOR_VERSION_MIN=${WATCHOS_SIMULATOR_VERSION_MIN-"4.0.0"}
+export IOS_SIMULATOR_VERSION_MIN=${IOS_SIMULATOR_VERSION_MIN-$IOS_VERSION_MIN}
 export WATCHOS_VERSION_MIN=${WATCHOS_VERSION_MIN-"4.0.0"}
-export TVOS_SIMULATOR_VERSION_MIN=${TVOS_SIMULATOR_VERSION_MIN-"9.0.0"}
+export WATCHOS_SIMULATOR_VERSION_MIN=${WATCHOS_SIMULATOR_VERSION_MIN-$WATCHOS_VERSION_MIN}
 export TVOS_VERSION_MIN=${TVOS_VERSION_MIN-"9.0.0"}
+export TVOS_SIMULATOR_VERSION_MIN=${TVOS_SIMULATOR_VERSION_MIN-$TVOS_VERSION_MIN}
 
 echo
 echo "Warnings related to headers being present but not usable are due to functions"
 echo "that didn't exist in the specified minimum iOS version level."
 echo "They can be safely ignored."
 echo
-echo "Define the LIBSODIUM_FULL_BUILD environment variable to build the full"
-echo "library (including all deprecated/undocumented/low-level functions)."
+echo "Define the LIBSODIUM_MINIMAL_BUILD environment variable to build a"
+echo "library without deprecated/undocumented/low-level functions."
 echo
 echo "Define the LIBSODIUM_SKIP_SIMULATORS environment variable to skip building"
 echo "the simulators libraries (iOS, watchOS, tvOS, visionOS simulators)."
 echo
 
-if [ -z "$LIBSODIUM_FULL_BUILD" ]; then
+if [ "$LIBSODIUM_MINIMAL_BUILD" ]; then
   export LIBSODIUM_ENABLE_MINIMAL_FLAG="--enable-minimal"
 else
   export LIBSODIUM_ENABLE_MINIMAL_FLAG=""
 fi
 
+IOS32_SUPPORTED=false
+[ "$(echo "$IOS_VERSION_MIN" | cut -d'.' -f1)" -lt "11" ] && IOS32_SUPPORTED=true
+
+I386_SIMULATOR_SUPPORTED=false
+[ "$(echo "$IOS_SIMULATOR_VERSION_MIN" | cut -d'.' -f1)" -lt "11" ] && I386_SIMULATOR_SUPPORTED=true
+
 VISIONOS_SUPPORTED=false
 [ -d "${XCODEDIR}/Platforms/XROS.platform" ] && VISIONOS_SUPPORTED=true
 
@@ -77,6 +93,15 @@ build_macos() {
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
 
+  ## macOS arm64e
+  export CFLAGS="-O3 -arch arm64e -mmacosx-version-min=${MACOS_VERSION_MIN}"
+  export LDFLAGS="-arch arm64e -mmacosx-version-min=${MACOS_VERSION_MIN}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$MACOS_ARM64E_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
+
   ## macOS x86_64
   export CFLAGS="-O3 -arch x86_64 -mmacosx-version-min=${MACOS_VERSION_MIN}"
   export LDFLAGS="-arch x86_64 -mmacosx-version-min=${MACOS_VERSION_MIN}"
@@ -92,23 +117,25 @@ build_ios() {
   export PATH="${BASEDIR}/usr/bin:$BASEDIR/usr/sbin:$PATH"
   export SDK="${BASEDIR}/SDKs/iPhoneOS.sdk"
 
-  ## 32-bit iOS
-  export CFLAGS="-O3 -mthumb -arch armv7 -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
-  export LDFLAGS="-mthumb -arch armv7 -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
+  if [ "$IOS32_SUPPORTED" = true ]; then
+    ## 32-bit iOS
+    export CFLAGS="-O3 -mthumb -arch armv7 -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
+    export LDFLAGS="-mthumb -arch armv7 -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
 
-  make distclean >/dev/null 2>&1
-  ./configure --host=arm-apple-darwin23 --prefix="$IOS32_PREFIX" \
-    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
-  make -j${PROCESSORS} install || exit 1
+    make distclean >/dev/null 2>&1
+    ./configure --host=arm-apple-darwin23 --prefix="$IOS32_PREFIX" \
+      ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+    make -j${PROCESSORS} install || exit 1
 
-  ## 32-bit armv7s iOS
-  export CFLAGS="-O3 -mthumb -arch armv7s -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
-  export LDFLAGS="-mthumb -arch armv7s -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
+    ## 32-bit armv7s iOS
+    export CFLAGS="-O3 -mthumb -arch armv7s -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
+    export LDFLAGS="-mthumb -arch armv7s -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
 
-  make distclean >/dev/null 2>&1
-  ./configure --host=arm-apple-darwin23 --prefix="$IOS32s_PREFIX" \
-    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
-  make -j${PROCESSORS} install || exit 1
+    make distclean >/dev/null 2>&1
+    ./configure --host=arm-apple-darwin23 --prefix="$IOS32s_PREFIX" \
+      ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+    make -j${PROCESSORS} install || exit 1
+  fi
 
   ## 64-bit iOS
   export CFLAGS="-O3 -arch arm64 -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
@@ -118,6 +145,15 @@ build_ios() {
   ./configure --host=aarch64-apple-darwin23 --prefix="$IOS64_PREFIX" \
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
+
+  ## 64-bit iOS arm64e
+  export CFLAGS="-O3 -arch arm64e -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
+  export LDFLAGS="-arch arm64e -isysroot ${SDK} -mios-version-min=${IOS_VERSION_MIN}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$IOS64E_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
 }
 
 build_ios_simulator() {
@@ -134,15 +170,26 @@ build_ios_simulator() {
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
 
-  ## i386 simulator
-  export CFLAGS="-O3 -arch i386 -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
-  export LDFLAGS="-arch i386 -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
+  ## arm64e simulator
+  export CFLAGS="-O3 -arch arm64e -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
+  export LDFLAGS="-arch arm64e -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
 
   make distclean >/dev/null 2>&1
-  ./configure --host=i686-apple-darwin23 --prefix="$IOS_SIMULATOR_I386_PREFIX" \
+  ./configure --host=aarch64-apple-darwin23 --prefix="$IOS_SIMULATOR_ARM64E_PREFIX" \
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
 
+  if [ "$I386_SIMULATOR_SUPPORTED" = true ]; then
+    ## i386 simulator
+    export CFLAGS="-O3 -arch i386 -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
+    export LDFLAGS="-arch i386 -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
+
+    make distclean >/dev/null 2>&1
+    ./configure --host=i686-apple-darwin23 --prefix="$IOS_SIMULATOR_I386_PREFIX" \
+      ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+    make -j${PROCESSORS} install || exit 1
+  fi
+
   ## x86_64 simulator
   export CFLAGS="-O3 -arch x86_64 -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
   export LDFLAGS="-arch x86_64 -isysroot ${SDK} -mios-simulator-version-min=${IOS_SIMULATOR_VERSION_MIN}"
@@ -184,6 +231,15 @@ build_watchos() {
   ./configure --host=aarch64-apple-darwin23 --prefix="$WATCHOS64_PREFIX" \
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
+
+  ## 64-bit arm64e watchOS
+  export CFLAGS="-O3 -mthumb -arch arm64e -isysroot ${SDK} -mwatchos-version-min=${WATCHOS_VERSION_MIN}"
+  export LDFLAGS="-mthumb -arch arm64e -isysroot ${SDK} -mwatchos-version-min=${WATCHOS_VERSION_MIN}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$WATCHOS64E_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
 }
 
 build_watchos_simulator() {
@@ -200,6 +256,15 @@ build_watchos_simulator() {
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
 
+  ## arm64e simulator
+  export CFLAGS="-O3 -arch arm64e -isysroot ${SDK} -mwatchos-simulator-version-min=${WATCHOS_SIMULATOR_VERSION_MIN}"
+  export LDFLAGS="-arch arm64e -isysroot ${SDK} -mwatchos-simulator-version-min=${WATCHOS_SIMULATOR_VERSION_MIN}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$WATCHOS_SIMULATOR_ARM64E_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
+
   ## i386 simulator
   export CFLAGS="-O3 -arch i386 -isysroot ${SDK} -mwatchos-simulator-version-min=${WATCHOS_SIMULATOR_VERSION_MIN}"
   export LDFLAGS="-arch i386 -isysroot ${SDK} -mwatchos-simulator-version-min=${WATCHOS_SIMULATOR_VERSION_MIN}"
@@ -232,6 +297,15 @@ build_tvos() {
   ./configure --host=aarch64-apple-darwin23 --prefix="$TVOS_PREFIX" \
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
+
+  ## 64-bit tvOS
+  export CFLAGS="-O3 -arch arm64e -isysroot ${SDK} -mtvos-version-min=${TVOS_VERSION_MIN}"
+  export LDFLAGS="-arch arm64e -isysroot ${SDK} -mtvos-version-min=${TVOS_VERSION_MIN}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$TVOSE_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
 }
 
 build_tvos_simulator() {
@@ -248,6 +322,15 @@ build_tvos_simulator() {
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
 
+  ## arm64e simulator
+  export CFLAGS="-O3 -arch arm64e -isysroot ${SDK} -mtvos-simulator-version-min=${TVOS_SIMULATOR_VERSION_MIN}"
+  export LDFLAGS="-arch arm64e -isysroot ${SDK} -mtvos-simulator-version-min=${TVOS_SIMULATOR_VERSION_MIN}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$TVOS_SIMULATOR_ARM64E_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
+
   ## x86_64 simulator
   export CFLAGS="-O3 -arch x86_64 -isysroot ${SDK} -mtvos-simulator-version-min=${TVOS_SIMULATOR_VERSION_MIN}"
   export LDFLAGS="-arch x86_64 -isysroot ${SDK} -mtvos-simulator-version-min=${TVOS_SIMULATOR_VERSION_MIN}"
@@ -270,6 +353,14 @@ build_visionos() {
   ./configure --host=aarch64-apple-darwin23 --prefix="$VISIONOS_PREFIX" \
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
+
+  export CFLAGS="-O3 -arch arm64e -isysroot ${SDK}"
+  export LDFLAGS="-arch arm64e -isysroot ${SDK}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$VISIONOSE_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
 }
 
 build_visionos_simulator() {
@@ -284,6 +375,14 @@ build_visionos_simulator() {
   ./configure --host=aarch64-apple-darwin23 --prefix="$VISIONOS_SIMULATOR_PREFIX" \
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
+
+  export CFLAGS="-O3 -arch arm64e -isysroot ${SDK}"
+  export LDFLAGS="-arch arm64e -isysroot ${SDK}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-darwin23 --prefix="$VISIONOSE_SIMULATOR_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
 }
 
 build_catalyst() {
@@ -300,6 +399,15 @@ build_catalyst() {
     ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
   make -j${PROCESSORS} install || exit 1
 
+  ## arm64e catalyst
+  export CFLAGS="-O3 -arch arm64e -target arm64e-apple-ios13.1-macabi -isysroot ${SDK}"
+  export LDFLAGS="-arch arm64e -target arm64e-apple-ios13.1-macabi -isysroot ${SDK}"
+
+  make distclean >/dev/null 2>&1
+  ./configure --host=aarch64-apple-ios --prefix="$CATALYST_ARM64E_PREFIX" \
+    ${LIBSODIUM_ENABLE_MINIMAL_FLAG} || exit 1
+  make -j${PROCESSORS} install || exit 1
+
   ## x86_64 catalyst
   export CFLAGS="-O3 -arch x86_64 -target x86_64-apple-ios13.1-macabi -isysroot ${SDK}"
   export LDFLAGS="-arch x86_64 -target x86_64-apple-ios13.1-macabi -isysroot ${SDK}"
@@ -355,6 +463,7 @@ cp -a "${MACOS_X86_64_PREFIX}/include" "${PREFIX}/macos/"
 for ext in a dylib; do
   lipo -create \
     "${MACOS_ARM64_PREFIX}/lib/libsodium.${ext}" \
+    "${MACOS_ARM64E_PREFIX}/lib/libsodium.${ext}" \
     "${MACOS_X86_64_PREFIX}/lib/libsodium.${ext}" \
     -output "${PREFIX}/macos/lib/libsodium.${ext}"
 done
@@ -364,10 +473,14 @@ echo "Bundling iOS targets..."
 mkdir -p "${PREFIX}/ios/lib"
 cp -a "${IOS64_PREFIX}/include" "${PREFIX}/ios/"
 for ext in a dylib; do
+  LIBRARY_PATHS="$IOS64_PREFIX/lib/libsodium.${ext}"
+  LIBRARY_PATHS="$LIBRARY_PATHS $IOS64E_PREFIX/lib/libsodium.${ext}"
+  if [ "$IOS32_SUPPORTED" = true ]; then
+    LIBRARY_PATHS="$LIBRARY_PATHS $IOS32_PREFIX/lib/libsodium.${ext}"
+    LIBRARY_PATHS="$LIBRARY_PATHS $IOS32s_PREFIX/lib/libsodium.${ext}"
+  fi
   lipo -create \
-    "$IOS32_PREFIX/lib/libsodium.${ext}" \
-    "$IOS32s_PREFIX/lib/libsodium.${ext}" \
-    "$IOS64_PREFIX/lib/libsodium.${ext}" \
+    ${LIBRARY_PATHS} \
     -output "$PREFIX/ios/lib/libsodium.${ext}"
 done
 
@@ -380,6 +493,7 @@ for ext in a dylib; do
     "${WATCHOS32_PREFIX}/lib/libsodium.${ext}" \
     "${WATCHOS64_32_PREFIX}/lib/libsodium.${ext}" \
     "${WATCHOS64_PREFIX}/lib/libsodium.${ext}" \
+    "${WATCHOS64E_PREFIX}/lib/libsodium.${ext}" \
     -output "${PREFIX}/watchos/lib/libsodium.${ext}"
 done
 
@@ -390,6 +504,7 @@ cp -a "${TVOS_PREFIX}/include" "${PREFIX}/tvos/"
 for ext in a dylib; do
   lipo -create \
     "$TVOS_PREFIX/lib/libsodium.${ext}" \
+    "$TVOSE_PREFIX/lib/libsodium.${ext}" \
     -output "$PREFIX/tvos/lib/libsodium.${ext}"
 done
 
@@ -401,6 +516,7 @@ if [ "$VISIONOS_SUPPORTED" = true ]; then
   for ext in a dylib; do
     lipo -create \
       "$VISIONOS_PREFIX/lib/libsodium.${ext}" \
+      "$VISIONOSE_PREFIX/lib/libsodium.${ext}" \
       -output "$PREFIX/visionos/lib/libsodium.${ext}"
   done
 fi
@@ -415,6 +531,7 @@ for ext in a dylib; do
   fi
   lipo -create \
     "${CATALYST_ARM64_PREFIX}/lib/libsodium.${ext}" \
+    "${CATALYST_ARM64E_PREFIX}/lib/libsodium.${ext}" \
     "${CATALYST_X86_64_PREFIX}/lib/libsodium.${ext}" \
     -output "${PREFIX}/catalyst/lib/libsodium.${ext}"
 done
@@ -425,10 +542,14 @@ if [ -z "$LIBSODIUM_SKIP_SIMULATORS" ]; then
   mkdir -p "${PREFIX}/ios-simulators/lib"
   cp -a "${IOS_SIMULATOR_X86_64_PREFIX}/include" "${PREFIX}/ios-simulators/"
   for ext in a dylib; do
+    LIBRARY_PATHS="${IOS_SIMULATOR_ARM64_PREFIX}/lib/libsodium.${ext}"
+    LIBRARY_PATHS="$LIBRARY_PATHS ${IOS_SIMULATOR_ARM64E_PREFIX}/lib/libsodium.${ext}"
+    LIBRARY_PATHS="$LIBRARY_PATHS ${IOS_SIMULATOR_X86_64_PREFIX}/lib/libsodium.${ext}"
+    if [ "$I386_SIMULATOR_SUPPORTED" = true ]; then
+      LIBRARY_PATHS="$LIBRARY_PATHS ${IOS_SIMULATOR_I386_PREFIX}/lib/libsodium.${ext}"
+    fi
     lipo -create \
-      "${IOS_SIMULATOR_ARM64_PREFIX}/lib/libsodium.${ext}" \
-      "${IOS_SIMULATOR_I386_PREFIX}/lib/libsodium.${ext}" \
-      "${IOS_SIMULATOR_X86_64_PREFIX}/lib/libsodium.${ext}" \
+      ${LIBRARY_PATHS} \
       -output "${PREFIX}/ios-simulators/lib/libsodium.${ext}" || exit 1
   done
 
@@ -439,6 +560,7 @@ if [ -z "$LIBSODIUM_SKIP_SIMULATORS" ]; then
   for ext in a dylib; do
     lipo -create \
       "${WATCHOS_SIMULATOR_ARM64_PREFIX}/lib/libsodium.${ext}" \
+      "${WATCHOS_SIMULATOR_ARM64E_PREFIX}/lib/libsodium.${ext}" \
       "${WATCHOS_SIMULATOR_I386_PREFIX}/lib/libsodium.${ext}" \
       "${WATCHOS_SIMULATOR_X86_64_PREFIX}/lib/libsodium.${ext}" \
       -output "${PREFIX}/watchos-simulators/lib/libsodium.${ext}"
@@ -451,6 +573,7 @@ if [ -z "$LIBSODIUM_SKIP_SIMULATORS" ]; then
   for ext in a dylib; do
     lipo -create \
       "${TVOS_SIMULATOR_ARM64_PREFIX}/lib/libsodium.${ext}" \
+      "${TVOS_SIMULATOR_ARM64E_PREFIX}/lib/libsodium.${ext}" \
       "${TVOS_SIMULATOR_X86_64_PREFIX}/lib/libsodium.${ext}" \
       -output "${PREFIX}/tvos-simulators/lib/libsodium.${ext}" || exit 1
   done
@@ -463,6 +586,7 @@ if [ -z "$LIBSODIUM_SKIP_SIMULATORS" ]; then
     for ext in a dylib; do
       lipo -create \
         "${VISIONOS_SIMULATOR_PREFIX}/lib/libsodium.${ext}" \
+        "${VISIONOSE_SIMULATOR_PREFIX}/lib/libsodium.${ext}" \
         -output "${PREFIX}/visionos-simulators/lib/libsodium.${ext}" || exit 1
     done
   fi
@@ -477,16 +601,16 @@ for f in macos ios watchos tvos visionos catalyst; do
   if [ "$VISIONOS_SUPPORTED" = false ] && [ "$f" = "visionos" ]; then
     continue
   fi
-  XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -library ${PREFIX}/${f}/lib/libsodium.a"
-  XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -headers ${PREFIX}/${f}/include"
+  XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -library $(readlink -f ${PREFIX}/${f}/lib/libsodium.a)"
+  XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -headers $(readlink -f ${PREFIX}/${f}/include)"
 done
 if [ -z "$LIBSODIUM_SKIP_SIMULATORS" ]; then
   for f in ios-simulators watchos-simulators tvos-simulators visionos-simulators; do
     if [ "$VISIONOS_SUPPORTED" = false ] && [ "$f" = "visionos-simulators" ]; then
       continue
     fi
-    XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -library ${PREFIX}/${f}/lib/libsodium.a"
-    XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -headers ${PREFIX}/${f}/include"
+    XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -library $(readlink -f ${PREFIX}/${f}/lib/libsodium.a)"
+    XCFRAMEWORK_ARGS="${XCFRAMEWORK_ARGS} -headers $(readlink -f ${PREFIX}/${f}/include)"
   done
 fi
 xcodebuild -create-xcframework \
